searchData={"items":[{"type":"module","title":"LibOss","doc":"# LibOss\n\nLibOss是Elixir实现的一个[阿里云oss](https://help.aliyun.com/product/31815.html)的SDK，目前支持的功能有：\n\n- [ ] Object:\n  - [ ] 基础操作:\n    - [x] 上传文件\n    - [x] 获取文件\n    - [x] 删除文件\n    - [x] 删除多个文件\n    - [x] 获取前端直传签名\n    - [x] 文件在bucket间拷贝\n    - [x] 追加写文件\n    - [x] 获取文件元信息\n    - [ ] 通过HTML表单上传的方式将文件\n    - [ ] 归档解冻\n    - [ ] 执行SQL语句\n\n  - [x] 分片上传:\n    - [x] 分片上传发起\n    - [x] 分片上传完成\n    - [x] 分片上传取消\n    - [x] 分片上传列表\n    - [x] 列举指定uploadid已经成功上传的part\n\n  - [x] 权限控制ACL\n    - [x] 设置文件ACL\n    - [x] 获取文件ACL\n  - [x] 软连接\n    - [x] 创建软连接\n    - [x] 获取软连接\n  - [x] 标签\n    - [x] 设置标签\n    - [x] 获取标签\n    - [x] 删除标签\n \n- [ ] Bucket:\n  - [x] 基础操作:\n    - [x] 创建bucket\n    - [x] 删除bucket\n    - [x] 获取bucket中文件\n    - [x] 获取bucket中文件V2\n    - [x] 查看bucket的相关信息\n    - [x] 获取bucket存储容量以及文件（Object）数量\n    - [x] 查看bucket的位置信息\n\n  - [ ] 接入点\n    - [ ] 创建接入点\n    - [ ] 删除接入点\n    - [ ] 获取接入点\n    - [ ] 列举接入点\n    - [ ] 配置接入点策略配置\n    - [ ] 获取接入点策略配置\n    - [ ] 删除接入点策略配置\n\n  - [x] 权限控制\n    - [x] 设置bucket ACL\n    - [x] 获取bucket ACL\n\n  - [ ] 生命周期\n  - [ ] 传输加速\n  - [ ] 版本控制\n  - [ ] 数据复制\n  - [ ] 授权策略\n  - [ ] 清单\n  - [ ] 日志管理\n  - [ ] 静态网站\n  - [ ] 防盗链\n  - [ ] 标签\n  - [ ] 加密\n  - [ ] 请求者付费\n  - [ ] 访问跟踪\n  - [ ] 数据索引\n  - [ ] 高防\n  - [ ] 资源组\n  - [ ] 自定义域名\n  - [ ] 图片样式\n  - [ ] 归档直读\n\n- [ ] LiveChannel","ref":"LibOss.html"},{"type":"module","title":"使用方法 - LibOss","doc":"```elixir\nMix.install([\n  {:lib_oss, \"~> 0.1\"}\n])\n\n# 创建一个oss客户端\ndefmodule MyOss do\n  use LibOss, otp_app: :my_app\nend\n\n# 配置客户端\nconfig :my_app, MyOss,\n    endpoint: \"oss-cn-somewhere.aliyuncs.com\",\n    access_key_id: \"your access key id\",\n    access_key_secret: \"your access key secret\"\n\n# 在superivsor中启动\nSupervisor.start_link(\n  [\n    MyOss\n  ],\n  strategy: :one_for_one\n)\n\n# 上传文件\n{:ok, content} = File.read(\"./test.txt\")\nMyOss.put_object(\"hope-data\", \"/test/test.txt\", content)\n```\n\n更多使用方法请参考[API文档](https://hexdocs.pm/lib_oss/LibOss.html)","ref":"LibOss.html#module-%E4%BD%BF%E7%94%A8%E6%96%B9%E6%B3%95"},{"type":"module","title":"LibOss.Debug","doc":"Debug tools","ref":"LibOss.Debug.html"},{"type":"function","title":"LibOss.Debug.debug/1","doc":"","ref":"LibOss.Debug.html#debug/1"},{"type":"function","title":"LibOss.Debug.stacktrace/1","doc":"","ref":"LibOss.Debug.html#stacktrace/1"},{"type":"behaviour","title":"LibOss.Http","doc":"behavior os http transport","ref":"LibOss.Http.html"},{"type":"callback","title":"LibOss.Http.do_request/2","doc":"","ref":"LibOss.Http.html#c:do_request/2"},{"type":"module","title":"LibOss.Http.Finch","doc":"Implement LibOss.Http behavior with Finch","ref":"LibOss.Http.Finch.html"},{"type":"function","title":"LibOss.Http.Finch.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LibOss.Http.Finch.html#child_spec/1"},{"type":"function","title":"LibOss.Http.Finch.handle_do_request/2","doc":"","ref":"LibOss.Http.Finch.html#handle_do_request/2"},{"type":"function","title":"LibOss.Http.Finch.start_link/1","doc":"","ref":"LibOss.Http.Finch.html#start_link/1"},{"type":"module","title":"LibOss.Model.Http.Request","doc":"http request","ref":"LibOss.Model.Http.Request.html"},{"type":"function","title":"LibOss.Model.Http.Request.url/1","doc":"","ref":"LibOss.Model.Http.Request.html#url/1"},{"type":"type","title":"LibOss.Model.Http.Request.t/0","doc":"","ref":"LibOss.Model.Http.Request.html#t:t/0"},{"type":"module","title":"LibOss.Model.Http.Response","doc":"http response","ref":"LibOss.Model.Http.Response.html"},{"type":"type","title":"LibOss.Model.Http.Response.t/0","doc":"","ref":"LibOss.Model.Http.Response.html#t:t/0"},{"type":"module","title":"LibOss.Typespecs","doc":"some typespecs","ref":"LibOss.Typespecs.html"},{"type":"type","title":"LibOss.Typespecs.access_point_name/0","doc":"","ref":"LibOss.Typespecs.html#t:access_point_name/0"},{"type":"type","title":"LibOss.Typespecs.acl/0","doc":"","ref":"LibOss.Typespecs.html#t:acl/0"},{"type":"type","title":"LibOss.Typespecs.body/0","doc":"","ref":"LibOss.Typespecs.html#t:body/0"},{"type":"type","title":"LibOss.Typespecs.bucket/0","doc":"","ref":"LibOss.Typespecs.html#t:bucket/0"},{"type":"type","title":"LibOss.Typespecs.dict/0","doc":"","ref":"LibOss.Typespecs.html#t:dict/0"},{"type":"type","title":"LibOss.Typespecs.etag/0","doc":"","ref":"LibOss.Typespecs.html#t:etag/0"},{"type":"type","title":"LibOss.Typespecs.headers/0","doc":"","ref":"LibOss.Typespecs.html#t:headers/0"},{"type":"type","title":"LibOss.Typespecs.host/0","doc":"","ref":"LibOss.Typespecs.html#t:host/0"},{"type":"type","title":"LibOss.Typespecs.http_status/0","doc":"","ref":"LibOss.Typespecs.html#t:http_status/0"},{"type":"type","title":"LibOss.Typespecs.method/0","doc":"","ref":"LibOss.Typespecs.html#t:method/0"},{"type":"type","title":"LibOss.Typespecs.name/0","doc":"","ref":"LibOss.Typespecs.html#t:name/0"},{"type":"type","title":"LibOss.Typespecs.object/0","doc":"","ref":"LibOss.Typespecs.html#t:object/0"},{"type":"type","title":"LibOss.Typespecs.on_start/0","doc":"","ref":"LibOss.Typespecs.html#t:on_start/0"},{"type":"type","title":"LibOss.Typespecs.opts/0","doc":"","ref":"LibOss.Typespecs.html#t:opts/0"},{"type":"type","title":"LibOss.Typespecs.params/0","doc":"","ref":"LibOss.Typespecs.html#t:params/0"},{"type":"type","title":"LibOss.Typespecs.part_num/0","doc":"","ref":"LibOss.Typespecs.html#t:part_num/0"},{"type":"type","title":"LibOss.Typespecs.upload_id/0","doc":"","ref":"LibOss.Typespecs.html#t:upload_id/0"},{"type":"module","title":"LibOss.Utils","doc":"utils","ref":"LibOss.Utils.html"},{"type":"function","title":"LibOss.Utils.debug/1","doc":"","ref":"LibOss.Utils.html#debug/1"},{"type":"function","title":"LibOss.Utils.do_sign/2","doc":"","ref":"LibOss.Utils.html#do_sign/2"},{"type":"function","title":"LibOss.Utils.stacktrace/1","doc":"","ref":"LibOss.Utils.html#stacktrace/1"},{"type":"exception","title":"LibOss.Exception","doc":"General exception with an optional string, map, or Keyword list stored\nin exception details","ref":"LibOss.Exception.html"},{"type":"function","title":"LibOss.Exception.new/2","doc":"","ref":"LibOss.Exception.html#new/2"},{"type":"type","title":"LibOss.Exception.t/0","doc":"","ref":"LibOss.Exception.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}